@@ -502,7 +502,8 @@ class Context(Configuration):
                                 ('PYTHONPATH', os.path.dirname(CONDA_PACKAGE_ROOT) + '{}{}'.format(
                                     os.pathsep, os.environ.get('PYTHONPATH', ''))),
                                 ('_CE_M', '-m'),
-                                ('_CE_CONDA', 'conda')])
+                                ('_CE_CONDA', 'conda'),
+                                ('CONDA_PYTHON_EXE', sys.executable)])
         else:
             bin_dir = 'Scripts' if on_win else 'bin'
             exe = 'conda.exe' if on_win else 'conda'
@@ -510,7 +511,8 @@ class Context(Configuration):
             # error-on-undefined.
             return OrderedDict([('CONDA_EXE', os.path.join(sys.prefix, bin_dir, exe)),
                                 ('_CE_M', ''),
-                                ('_CE_CONDA', '')])
+                                ('_CE_CONDA', ''),
+                                ('CONDA_PYTHON_EXE', sys.executable)])
 
     @memoizedproperty
     def channel_alias(self):
@@ -1107,6 +1109,7 @@ def conda_in_private_env():
 
 
 def reset_context(search_path=SEARCH_PATH, argparse_args=None):
+    global context
     context.__init__(search_path, argparse_args)
     context.__dict__.pop('_Context__conda_build', None)
     from ..models.channel import Channel
@@ -1180,17 +1183,19 @@ def stack_context_default(pushing, argparse_args=None):
     return stack_context(pushing, search_path=(), argparse_args=argparse_args)
 
 
-def replace_context(pushing, search_path=SEARCH_PATH, argparse_args=None):
+def replace_context(pushing=None, search_path=SEARCH_PATH, argparse_args=None):
+    # pushing arg intentionally not used here, but kept for API compatibility
     return context_stack.replace(search_path, argparse_args)
 
 
-def replace_context_default(pushing, argparse_args=None):
+def replace_context_default(pushing=None, argparse_args=None):
+    # pushing arg intentionally not used here, but kept for API compatibility
     return context_stack.replace(search_path=(), argparse_args=argparse_args)
 
 
 # Tests that want to only declare 'I support the project-wide default for how to
 # manage stacking of contexts'. Tests that are known to be careful with context
-# can use `replace_context_with_default` which might be faster, though it should
+# can use `replace_context_default` which might be faster, though it should
 # be a stated goal to set conda_tests_ctxt_mgmt_def_pol to replace_context_default
 # and not to stack_context_default.
 conda_tests_ctxt_mgmt_def_pol = replace_context_default
@@ -1269,7 +1274,7 @@ def determine_target_prefix(ctx, args=None):
     elif prefix_path is not None:
         return expand(prefix_path)
     else:
-        disallowed_chars = ('/', ' ', ':')
+        disallowed_chars = ('/', ' ', ':', '#')
         if any(_ in prefix_name for _ in disallowed_chars):
             from ..exceptions import CondaValueError
             builder = ["Invalid environment name: '" + prefix_name + "'"]
