@@ -81,6 +81,11 @@ CONDA_INITIALIZE_RE_BLOCK = (
     r"([\s\S]*?)"
     r"# <<< conda initialize <<<(?:\n|\r\n)?")
 
+CONDA_INITIALIZE_PS_RE_BLOCK = (
+    r"^#region conda initialize(?:\n|\r\n)"
+    r"([\s\S]*?)"
+    r"#endregion(?:\n|\r\n)?")
+
 class Result:
     NEEDS_SUDO = "needs sudo"
     MODIFIED = "modified"
@@ -184,6 +189,7 @@ def initialize_dev(shell, dev_env_prefix=None, conda_source_root=None):
         'CONDA_PREFIX',
         'CONDA_PREFIX_1',
         'CONDA_PREFIX_2',
+        'CONDA_PYTHON_EXE',
         'CONDA_PROMPT_MODIFIER',
         'CONDA_SHLVL',
     )
@@ -1371,7 +1377,7 @@ def init_powershell_user(target_path, conda_prefix, reverse):
     # TODO: comment out old ipmos and Import-Modules.
 
     if reverse:
-        profile_content = re.sub(r"\s*\#region conda initialize.*\#endregion",
+        profile_content = re.sub(CONDA_INITIALIZE_PS_RE_BLOCK,
                                  "",
                                  profile_content,
                                  count=1,
@@ -1384,7 +1390,7 @@ def init_powershell_user(target_path, conda_prefix, reverse):
         if "#region conda initialize" not in profile_content:
             profile_content += "\n{}\n".format(conda_initialize_content)
         else:
-            profile_content = re.sub(r"\#region conda initialize.*\#endregion",
+            profile_content = re.sub(CONDA_INITIALIZE_PS_RE_BLOCK,
                                      "__CONDA_REPLACE_ME_123__",
                                      profile_content,
                                      count=1,
